print("----------------------- MAIN DATA ----------------------")
data1=read.csv("mainExperimentData.csv")

#Count of Observations
print("COUNT OF OBSERVATIONS:")
countData=subset(data1,cNumber==1)
table(countData$Structure,countData$Visibility,countData$Incentives,countData$Population)


#Permutation Tests
print("PERMUTATION TESTS:")
library(plyr)
library(dplyr)
library(boot)

my_quantile=function(temp,i){
  return(c(quantile(temp[i],probs=c(.25,.5,.75),na.rm=T)));
}
my_permutation_tests=function(sample1,sample2){
  
  ns1=length(sample1)
  ns2=length(sample2)
  n=ns1+ns2
  all=c(sample1,sample2)
  
  original3=quantile(sample1,.25,na.rm=T)-quantile(sample2,.25,na.rm=T)
  original4=quantile(sample1,.5,na.rm=T)-quantile(sample2,.5,na.rm=T)
  original5=quantile(sample1,.75,na.rm=T)-quantile(sample2,.75,na.rm=T)
  
  stat_dist3=NULL
  stat_dist4=NULL
  stat_dist5=NULL
  
  for(i in 1:10000){
    pick1=sample(1:n,size=ns1,replace=FALSE)
    pick2=setdiff(1:n,pick1)
    s1=all[pick1]
    s2=all[pick2]

    st3=quantile(s1,.25,na.rm=T)-quantile(s2,.25,na.rm=T)
    st4=quantile(s1,.5,na.rm=T)-quantile(s2,.5,na.rm=T)
    st5=quantile(s1,.75,na.rm=T)-quantile(s2,.75,na.rm=T)
    
    stat_dist3=c(stat_dist3,st3)
    stat_dist4=c(stat_dist4,st4)
    stat_dist5=c(stat_dist5,st5)
    
  }

  prob_left3=(sum(stat_dist3<=original3)+1)/10001
  prob_right3=(sum(stat_dist3>=original3)+1)/10001
  
  prob_left4=(sum(stat_dist4<=original4)+1)/10001
  prob_right4=(sum(stat_dist4>=original4)+1)/10001

  
  prob_left5=(sum(stat_dist5<=original5)+1)/10001
  prob_right5=(sum(stat_dist5>=original5)+1)/10001

  
  return(c(prob_left3,prob_left4,prob_left5,prob_right3,prob_right4,prob_right5))
}

data1$Visibility=revalue(data1$Visibility, c("Blocked.Visibility"="Blocked Visibility", "Full.Visibility"="Full Visibility"))
data1$Incentives=revalue(data1$Incentives, c("Flat"="Flat", "PerCart"="Per Cart"))
data1$Population=revalue(data1$Population, c("Lab"="Lab", "M.Turk"="M-Turk"))
data1$Structure=relevel(data1$Structure, ref="Single")


merged_data_high=subset(data1,cNumber==1)
dim1=c("Flat", "Per Cart")
dim2=c("Lab","M-Turk")
dim3=c("Parallel","Single")
dim4=c("Blocked Visibility","Full Visibility")


moments=c("25th perc.","50th perc.","75th perc.")


for(d1 in dim1){
  for(d3 in dim3){
    for(d2 in dim2){
      for(d4 in dim4){
        
        for(k1 in dim1){
          for(k3 in dim3){
            for(k2 in dim2){
              for(k4 in dim4){
                
                if(d1==k1 & d2==k2 & d3==k3 & d4==k4){
                  
                  print(paste("----",d1,"x",d3,"x",d2,"x",d4,"----"))
                  temp_sample=subset(merged_data_high,Visibility==d4 & Incentives==d1 & Structure==d3 & Population==d2)$MEDIAN_SPEED
                  
                  res=boot(data=temp_sample,R=1000,statistic=my_quantile)
                  
                  for(i in 1:3){
                    print(paste(moments[i],round(res$t0[i],2),"(",round(sd(res$t[,i]),2),")"))
                  }   
                  
                } 
                
                if(d1==k1 & d2==k2 & d3=="Parallel"& k3=="Single" & d4==k4){
                  print(paste("---",d1,"x",d2,"x",d4,"-test->",d3,"vs",k3))
                  temp_sample1=subset(merged_data_high,Visibility==d4 & Incentives==d1 & Structure==d3 & Population==d2)$MEDIAN_SPEED
                  temp_sample2=subset(merged_data_high,Visibility==k4 & Incentives==k1 & Structure==k3 & Population==k2)$MEDIAN_SPEED
                  
                  tests=my_permutation_tests(temp_sample1,temp_sample2)
                  
                  res1=boot(data=temp_sample1,R=1000,statistic=my_quantile)
                  res2=boot(data=temp_sample2,R=1000,statistic=my_quantile)
                  
                  for(i in 1:3){
                    temp_string="";
                    if(res1$t0[i]>res2$t0[i]){
                      print(paste(round(res1$t0[i],2),">",round(res2$t0[i],2)," p-value=",round(tests[3+i],3)))
                    }else{
                      print(paste(round(res1$t0[i],2),"<",round(res2$t0[i],2)," p-value=",round(tests[i],3)))
                    }
                    
                  }   
                  
                } 
                
                if(d1==k1 & d2==k2 & d3==k3 & d4=="Blocked Visibility" & k4=="Full Visibility"){
                  print(paste("---",d1,"x",d2,"x",d3,"-test->",d4,"vs",k4))
                  temp_sample1=subset(merged_data_high,Visibility==d4 & Incentives==d1 & Structure==d3 & Population==d2)$MEDIAN_SPEED
                  temp_sample2=subset(merged_data_high,Visibility==k4 & Incentives==k1 & Structure==k3 & Population==k2)$MEDIAN_SPEED
                  
                  tests=my_permutation_tests(temp_sample1,temp_sample2)
                  
                  
                  res1=boot(data=temp_sample1,R=1000,statistic=my_quantile)
                  res2=boot(data=temp_sample2,R=1000,statistic=my_quantile)
                  
                  for(i in 1:3){
                    temp_string="";
                    if(res1$t0[i]>res2$t0[i]){
                      print(paste(round(res1$t0[i],2),">",round(res2$t0[i],2)," p-value=",round(tests[3+i],3)))
                    }else{
                      print(paste(round(res1$t0[i],2),"<",round(res2$t0[i],2)," p-value=",round(tests[i],3)))
                    }
                    
                  }  
                    
                  
                }
                
              }}}}  
        

        
      }}
    
    
  }}




#Robust Regression Analysis
print("ROBUST REGRESSION ANALYSIS:")
library(robustbase)
merged_data_high=subset(data1,cNumber==1)
regression_data=subset(merged_data_high,GENDER!="NoResponse")
regression_data$Structure=relevel(regression_data$Structure,ref="Single")
regression_data$Visibility=relevel(regression_data$Visibility,ref="Full Visibility")

# Robust Regression on Lab DATA
regression_data_lab=subset(regression_data, Population=="Lab")
regression_data_lab$GENDER=as.factor(as.character(regression_data_lab$GENDER))
regression_data_lab$AGE=relevel(regression_data_lab$AGE,ref="BornBefore1990")

lm1=lmrob(MEDIAN_SPEED~Structure+Visibility*Incentives+AGE+GENDER+MANAGERIAL, data=regression_data_lab )
summary(lm1)
print(paste("D.F.:",lm1$degree.freedom))


# Robust Regression on M-Turk DATA
regression_data_mturk=subset(regression_data, Population=="M-Turk")
regression_data_mturk$GENDER=as.factor(as.character(regression_data_mturk$GENDER))
regression_data_mturk$AGE=relevel(regression_data_mturk$AGE,ref="BornBefore1990")
regression_data_mturk$DEVICE=relevel(regression_data_mturk$DEVICE,ref="Mouse")

lm2=lmrob(MEDIAN_SPEED~Structure+Visibility*Incentives+AGE+GENDER+MANAGERIAL+DEVICE, data=regression_data_mturk )
summary(lm2)
print(paste("D.F.:",lm2$degree.freedom))



print("----------------------- ROBUSTNESS CHECK 1: LOW LOAD ----------------------")
data2=read.csv("RobCheck1LowData.csv")

#Count of Observations
print("COUNT OF OBSERVATIONS:")
countData=subset(data2,cNumber==1)
table(countData$Structure,countData$Visibility,countData$Incentives,countData$Population)

data2$Visibility=revalue(data2$Visibility, c("Blocked.Visibility"="Blocked Visibility", "Full.Visibility"="Full Visibility"))
data2$Incentives=revalue(data2$Incentives, c("Flat"="Flat", "PerCart"="Per Cart"))
data2$Population=revalue(data2$Population, c("M.Turk"="M-Turk"))
data2$Structure=relevel(data2$Structure, ref="Single")


merged_data_high=subset(data2,cNumber==1)
dim1=c("Flat", "Per Cart")
dim2=c("M-Turk")
dim3=c("Parallel","Single")
dim4=c("Blocked Visibility","Full Visibility")


moments=c("25th perc.","50th perc.","75th perc.")


for(d1 in dim1){
  for(d3 in dim3){
    for(d2 in dim2){
      for(d4 in dim4){
        
        for(k1 in dim1){
          for(k3 in dim3){
            for(k2 in dim2){
              for(k4 in dim4){
                
                if(d1==k1 & d2==k2 & d3==k3 & d4==k4){
                  
                  print(paste("----",d1,"x",d3,"x",d2,"x",d4,"----"))
                  temp_sample=subset(merged_data_high,Visibility==d4 & Incentives==d1 & Structure==d3 & Population==d2)$MEDIAN_SPEED
                  
                  res=boot(data=temp_sample,R=1000,statistic=my_quantile)
                  
                  for(i in 1:3){
                    print(paste(moments[i],round(res$t0[i],2),"(",round(sd(res$t[,i]),2),")"))
                  }   
                  
                } 
                
                if(d1==k1 & d2==k2 & d3=="Parallel"& k3=="Single" & d4==k4){
                  print(paste("---",d1,"x",d2,"x",d4,"-test->",d3,"vs",k3))
                  temp_sample1=subset(merged_data_high,Visibility==d4 & Incentives==d1 & Structure==d3 & Population==d2)$MEDIAN_SPEED
                  temp_sample2=subset(merged_data_high,Visibility==k4 & Incentives==k1 & Structure==k3 & Population==k2)$MEDIAN_SPEED
                  
                  tests=my_permutation_tests(temp_sample1,temp_sample2)
                  
                  res1=boot(data=temp_sample1,R=1000,statistic=my_quantile)
                  res2=boot(data=temp_sample2,R=1000,statistic=my_quantile)
                  
                  for(i in 1:3){
                    temp_string="";
                    if(res1$t0[i]>res2$t0[i]){
                      print(paste(round(res1$t0[i],2),">",round(res2$t0[i],2)," p-value=",round(tests[3+i],3)))
                    }else{
                      print(paste(round(res1$t0[i],2),"<",round(res2$t0[i],2)," p-value=",round(tests[i],3)))
                    }
                    
                  }   
                  
                } 
                
                if(d1==k1 & d2==k2 & d3==k3 & d4=="Blocked Visibility" & k4=="Full Visibility"){
                  print(paste("---",d1,"x",d2,"x",d3,"-test->",d4,"vs",k4))
                  temp_sample1=subset(merged_data_high,Visibility==d4 & Incentives==d1 & Structure==d3 & Population==d2)$MEDIAN_SPEED
                  temp_sample2=subset(merged_data_high,Visibility==k4 & Incentives==k1 & Structure==k3 & Population==k2)$MEDIAN_SPEED
                  
                  tests=my_permutation_tests(temp_sample1,temp_sample2)
                  
                  
                  res1=boot(data=temp_sample1,R=1000,statistic=my_quantile)
                  res2=boot(data=temp_sample2,R=1000,statistic=my_quantile)
                  
                  for(i in 1:3){
                    temp_string="";
                    if(res1$t0[i]>res2$t0[i]){
                      print(paste(round(res1$t0[i],2),">",round(res2$t0[i],2)," p-value=",round(tests[3+i],3)))
                    }else{
                      print(paste(round(res1$t0[i],2),"<",round(res2$t0[i],2)," p-value=",round(tests[i],3)))
                    }
                    
                  }  
                  
                  
                }
                
              }}}}  
        
        
        
      }}
    
    
  }}


print("----------------------- ROBUSTNESS CHECK 2: COMP EMPHASIZED ----------------------")
data3=read.csv("RobCheck2EmphData.csv")

#Count of Observations
print("COUNT OF OBSERVATIONS:")
countData=subset(data3,cNumber==1)
table(countData$Structure,countData$Visibility,countData$Incentives,countData$Population)


merged_data_high=subset(data3,cNumber==1)
dim1=c("Flat")
dim2=c("M-Turk")
dim3=c("Parallel","Single")
dim4=c("Full Visibility")


moments=c("25th perc.","50th perc.","75th perc.")


for(d1 in dim1){
  for(d3 in dim3){
    for(d2 in dim2){
      for(d4 in dim4){
        
        for(k1 in dim1){
          for(k3 in dim3){
            for(k2 in dim2){
              for(k4 in dim4){
                
                if(d1==k1 & d2==k2 & d3==k3 & d4==k4){
                  
                  print(paste("----",d1,"x",d3,"x",d2,"x",d4,"----"))
                  temp_sample=subset(merged_data_high,Visibility==d4 & Incentives==d1 & Structure==d3 & Population==d2)$MEDIAN_SPEED
                  
                  res=boot(data=temp_sample,R=1000,statistic=my_quantile)
                  
                  for(i in 1:3){
                    print(paste(moments[i],round(res$t0[i],2),"(",round(sd(res$t[,i]),2),")"))
                  }   
                  
                } 
                
                if(d1==k1 & d2==k2 & d3=="Parallel"& k3=="Single" & d4==k4){
                  print(paste("---",d1,"x",d2,"x",d4,"-test->",d3,"vs",k3))
                  temp_sample1=subset(merged_data_high,Visibility==d4 & Incentives==d1 & Structure==d3 & Population==d2)$MEDIAN_SPEED
                  temp_sample2=subset(merged_data_high,Visibility==k4 & Incentives==k1 & Structure==k3 & Population==k2)$MEDIAN_SPEED
                  
                  tests=my_permutation_tests(temp_sample1,temp_sample2)
                  
                  res1=boot(data=temp_sample1,R=1000,statistic=my_quantile)
                  res2=boot(data=temp_sample2,R=1000,statistic=my_quantile)
                  
                  for(i in 1:3){
                    temp_string="";
                    if(res1$t0[i]>res2$t0[i]){
                      print(paste(round(res1$t0[i],2),">",round(res2$t0[i],2)," p-value=",round(tests[3+i],3)))
                    }else{
                      print(paste(round(res1$t0[i],2),"<",round(res2$t0[i],2)," p-value=",round(tests[i],3)))
                    }
                    
                  }   
                  
                } 
                
                if(d1==k1 & d2==k2 & d3==k3 & d4=="Blocked Visibility" & k4=="Full Visibility"){
                  print(paste("---",d1,"x",d2,"x",d3,"-test->",d4,"vs",k4))
                  temp_sample1=subset(merged_data_high,Visibility==d4 & Incentives==d1 & Structure==d3 & Population==d2)$MEDIAN_SPEED
                  temp_sample2=subset(merged_data_high,Visibility==k4 & Incentives==k1 & Structure==k3 & Population==k2)$MEDIAN_SPEED
                  
                  tests=my_permutation_tests(temp_sample1,temp_sample2)
                  
                  
                  res1=boot(data=temp_sample1,R=1000,statistic=my_quantile)
                  res2=boot(data=temp_sample2,R=1000,statistic=my_quantile)
                  
                  for(i in 1:3){
                    temp_string="";
                    if(res1$t0[i]>res2$t0[i]){
                      print(paste(round(res1$t0[i],2),">",round(res2$t0[i],2)," p-value=",round(tests[3+i],3)))
                    }else{
                      print(paste(round(res1$t0[i],2),"<",round(res2$t0[i],2)," p-value=",round(tests[i],3)))
                    }
                    
                  }  
                  
                  
                }
                
              }}}}  
        
        
        
      }}
    
    
  }}
