#Replication code for Shunko et al. (2018) MS Replication Project
#March 14, 2022

####
#Most code is copied from original R script included in the supplementary materials to the original article, except where indicated
###

print("##########BEGIN PRINTING RESULTS###########")
data1=read.csv("replication_data.csv") #this is the code for replication data

#Count of Observations
print("COUNT OF OBSERVATIONS:")
countData=subset(data1,cNumber==1)
table(countData$Structure,countData$Visibility,countData$Incentives,countData$Population,countData$Location) #edited to include location


#Permutation Tests
print("PERMUTATION TESTS:")
library(plyr)
library(dplyr)
library(boot)

my_quantile=function(temp,i){
  return(c(quantile(temp[i],probs=c(.25,.5,.75),na.rm=T)));
}
my_permutation_tests=function(sample1,sample2){
  
  ns1=length(sample1)
  ns2=length(sample2)
  n=ns1+ns2
  all=c(sample1,sample2)
  
  original3=quantile(sample1,.25,na.rm=T)-quantile(sample2,.25,na.rm=T)
  original4=quantile(sample1,.5,na.rm=T)-quantile(sample2,.5,na.rm=T)
  original5=quantile(sample1,.75,na.rm=T)-quantile(sample2,.75,na.rm=T)
  
  stat_dist3=NULL
  stat_dist4=NULL
  stat_dist5=NULL
  
  for(i in 1:10000){
    pick1=sample(1:n,size=ns1,replace=FALSE)
    pick2=setdiff(1:n,pick1)
    s1=all[pick1]
    s2=all[pick2]

    st3=quantile(s1,.25,na.rm=T)-quantile(s2,.25,na.rm=T)
    st4=quantile(s1,.5,na.rm=T)-quantile(s2,.5,na.rm=T)
    st5=quantile(s1,.75,na.rm=T)-quantile(s2,.75,na.rm=T)
    
    stat_dist3=c(stat_dist3,st3)
    stat_dist4=c(stat_dist4,st4)
    stat_dist5=c(stat_dist5,st5)
    
  }

  prob_left3=(sum(stat_dist3<=original3)+1)/10001
  prob_right3=(sum(stat_dist3>=original3)+1)/10001
  
  prob_left4=(sum(stat_dist4<=original4)+1)/10001
  prob_right4=(sum(stat_dist4>=original4)+1)/10001

  
  prob_left5=(sum(stat_dist5<=original5)+1)/10001
  prob_right5=(sum(stat_dist5>=original5)+1)/10001

  
  return(c(prob_left3,prob_left4,prob_left5,prob_right3,prob_right4,prob_right5))
}


merged_data_high=subset(data1,cNumber==1)


moments=c("25th perc.","50th perc.","75th perc.")


#####################
#We revised the permutation test code from the original R script to accommodate only the conditions we need.
#Note: numbers vary slightly each time due to the bootstrapping process
######################
##UW Madison
temp_sample1=subset(merged_data_high,Structure=="Parallel" & Location == "UWMadison")$MEDIAN_SPEED #This code is new
temp_sample2=subset(merged_data_high,Structure=="Single" & Location == "UWMadison")$MEDIAN_SPEED #This code is new
tests=my_permutation_tests(temp_sample1,temp_sample2)
res1=boot(data=temp_sample1,R=1000,statistic=my_quantile)
res2=boot(data=temp_sample2,R=1000,statistic=my_quantile)
print("Parallel vs. Single at UW Madison") #This code is new
for(i in 1:3){
  temp_string="";
  if(res1$t0[i]>res2$t0[i]){
    print(paste(round(res1$t0[i],2),">",round(res2$t0[i],2)," p-value=",round(tests[3+i],3)))
    }else{
      print(paste(round(res1$t0[i],2),"<",round(res2$t0[i],2)," p-value=",round(tests[i],3)))
      }
  }   

#getting the standard errors
temp_sample=subset(merged_data_high,Structure=="Parallel" & Location == "UWMadison")$MEDIAN_SPEED #This code is new

res=boot(data=temp_sample,R=1000,statistic=my_quantile)
print("parallel at UWMadison")
for(i in 1:3){
  print(paste(moments[i],round(res$t0[i],2),"(",round(sd(res$t[,i]),2),")"))
}
temp_sample=subset(merged_data_high,Structure=="Single" & Location == "UWMadison")$MEDIAN_SPEED #This code is new

res=boot(data=temp_sample,R=1000,statistic=my_quantile)
print("single at UWMadison") #This code is new
for(i in 1:3){
  print(paste(moments[i],round(res$t0[i],2),"(",round(sd(res$t[,i]),2),")"))
}



###########USC
temp_sample1=subset(merged_data_high,Structure=="Parallel" & Location == "USC")$MEDIAN_SPEED #This code is new
temp_sample2=subset(merged_data_high,Structure=="Single" & Location == "USC")$MEDIAN_SPEED #This code is new
tests=my_permutation_tests(temp_sample1,temp_sample2)
res1=boot(data=temp_sample1,R=1000,statistic=my_quantile)
res2=boot(data=temp_sample2,R=1000,statistic=my_quantile)
print("Parallel vs. Single at USC") #This code is new
for(i in 1:3){
  temp_string="";
  if(res1$t0[i]>res2$t0[i]){
    print(paste(round(res1$t0[i],2),">",round(res2$t0[i],2)," p-value=",round(tests[3+i],3)))
  }else{
    print(paste(round(res1$t0[i],2),"<",round(res2$t0[i],2)," p-value=",round(tests[i],3)))
  }
}   
#getting the standard errors
temp_sample=subset(merged_data_high,Structure=="Parallel" & Location == "USC")$MEDIAN_SPEED #This code is new

res=boot(data=temp_sample,R=1000,statistic=my_quantile)
print("parallel at USC")
for(i in 1:3){
  print(paste(moments[i],round(res$t0[i],2),"(",round(sd(res$t[,i]),2),")"))
}
temp_sample=subset(merged_data_high,Structure=="Single" & Location == "USC")$MEDIAN_SPEED #This code is new

res=boot(data=temp_sample,R=1000,statistic=my_quantile)
print("single at USC") #This code is new
for(i in 1:3){
  print(paste(moments[i],round(res$t0[i],2),"(",round(sd(res$t[,i]),2),")"))
}


#########
#Next, we adapt the original R code for robust regression analysis to accommodate the reduced number of conditions 
########
library(robustbase)
merged_data_high=subset(data1,cNumber==1)
regression_data=subset(merged_data_high,GENDER!="NoResponse")
regression_data$GENDER=as.factor(as.character(regression_data$GENDER))
regression_data$Structure=as.factor(as.character(regression_data$Structure))
regression_data$Structure=relevel(regression_data$Structure,ref="Single")


# Robust Regression on M-Turk DATA - UW-Madison
print("regression results for UW Madison") #This code is new
regression_data_mturk=subset(regression_data, Population=="M.Turk" & Location == "UWMadison") #This code is new

lm2=lmrob(MEDIAN_SPEED~Structure+AGE_1990+GENDER+MANAGERIAL+DEVICE, data=regression_data_mturk ) #This code is new, eliminated unused predictors
summary(lm2)
print(paste("D.F.:",lm2$degree.freedom))

# Robust Regression on M-Turk DATA - USC
print("regression results for USC") #This code is new
regression_data_mturk2=subset(regression_data, Population=="M.Turk" & Location == "USC") #This code is new

lm2b=lmrob(MEDIAN_SPEED~Structure+AGE_1990+GENDER+MANAGERIAL+DEVICE, data=regression_data_mturk2 ) #This code is new, eliminated unused predictors
summary(lm2b)
print(paste("D.F.:",lm2b$degree.freedom))




